v0.1.1
======

Features
--------

- Makes package PEP-561 compliant by adding py.typed file


v0.1.0
======

Features
--------

- Adds Pydantic models for k8s v1.30.0 (#1)
- Adds scripts for model generation (#2)
